<?php
/**
 * @file
 * Contains \Drupal\resume\Form\DeployForm.
 */
namespace Drupal\dpservices\Form;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\Core\Database\Database;
use Drupal\Core\TypedData\Exception\MissingDataException;
use Drupal\node\Entity\Node;
use Drupal\Core\Entity\Query\QueryFactory;
use Drupal\Core\Entity\Query;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\BaseFieldDefinition;


module_load_include('inc', 'dpservices' , 'dpservices.config.inc');

class DisplayBlock extends FormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'deploy_form_block';
  }
  
  public function buildForm(array $form, FormStateInterface $form_state) {
    if(db_table_exists('block_content__' . DP_FIELD_NODE_DEPLOY)) {
	    $query = \Drupal::database()->select('block_content', 'b');
      $query->join('block_content__' . DP_FIELD_BLOCK_DEPLOY , 'd', 'd.entity_id = b.id');
	    $query->join('block_content_field_data' , 'bfd', 'bfd.id = b.id');
      $query->fields('b', ['id']);
	    $query->fields('bfd', ['changed']);
      $query->orderBy('changed' , 'DESC');	
	    $query->condition('d.' . DP_FIELD_BLOCK_DEPLOY . '_value', 1);
      //For the pagination we need to extend the pagerselectextender and
      //limit in the query
      $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(10);
      $results = $pager->execute()->fetchAll();	
	    $header = [
        'title' => t('title'),  
        'type' => t('type'),
         'updated' => t('Updated'),	 
      ];
	    $output = array();
      foreach ($results AS $value) {
        if(isset($value->id)) {
	        $block_storage = \Drupal::entityTypeManager()->getStorage('block_content');
          $block = $block_storage->load($value->id);
		      $title = $block->get('info')->getvalue();
		      $type = $block->get('type')->getvalue();		
		      $title = $title[0]['value'];
		      $updated = $value->changed;
          $type = $type[0]['target_id'];
          $query = \Drupal::database()->select('dpservices' , 'n');
          $query->fields('n' , array('entity_id'));
          $query->condition('status', 0, "=");
          $query->condition('type', 'block', "=");
          $query->condition('entity_id', $value->id, "=");
          $results = $query->execute()->fetchAll();		
	        if(count($results) == 0) {
		        $output[$value->id] = [
	            'title' => $title,
              'type' => $type,
              'updated' => date("Y-m-d H:i:s" , $updated),			
	          ];
		      }		
	      }
      }	
      $form['table'] = [
        '#type' => 'tableselect',
        '#header' => $header,
        '#options' => $output,
        '#empty' => t('No blocks available for deployment.'),
      ];
      if(count($output) != 0) {  
        $form['datetime'] = [
          '#title' => 'Chose date to deploy (eg : m/d/Y h:i:sa) :',
          '#type' => 'datetime',
          '#size' => 20,
	        '#date_time_element' => 'text',
	        '#default_value' => '',
	        '#required' => true,
        ];
	      $form['actions']['#type'] = 'actions';
        $form['actions']['submit'] = array(
          '#type' => 'submit',
          '#value' => $this->t('Save'),
          '#button_type' => 'primary',
        );
	      $form['pager'] = array(
          '#type' => 'pager'
        );
	    }
      return $form;
    }
  }
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $date = $form_state->getValue('datetime')->format('d-m-Y h:i:sa');
	  $date = strtotime($date);
	  $arr_default_bid = $form_state->getValue('table');
	  if(count($arr_default_bid) > 0) {
      foreach($arr_default_bid as $value) {	  
	      if(isset($value) && !empty($value)) {
          $result = \Drupal::database()->insert('dpservices')
	        ->fields(['entity_id' => $value , 'type' => 'block' , 'deploy_date' => $date])->execute();
	      }	  
	    }
	  }
	  drupal_set_message('Deployment for Block submitted successfully.');		
  }  
} 