<?php
/**
 * @file
 * Contains \Drupal\resume\Form\DeployForm.
 */
namespace Drupal\dpservices\Form;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\Core\Database\Database;
use Drupal\Core\TypedData\Exception\MissingDataException;
use Drupal\node\Entity\Node;
use Drupal\Core\Entity\Query\QueryFactory;
use Drupal\Core\Entity\Query;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\dpservices\Logs\DpservicesLogError;

class DisplayContent extends FormBase {
  /**
   * {@inheritdoc}
   */
  protected $dp_username;
  protected $dp_password;
  public function __construct() {
    $this->setDeploySettings();   
  }

  public function getFormId() {
    return 'deploy_form';
  }
  
  public function buildForm(array $form, FormStateInterface $form_state) {
    if(db_table_exists('node__' . DP_FIELD_NODE_DEPLOY)) {    
      $query = \Drupal::database()->select('node', 'n');
      $query->join('node__' . DP_FIELD_NODE_DEPLOY , 'd', 'd.entity_id = n.nid');
	    $query->join('node_field_data' , 'nfd', 'nfd.nid = n.nid');
      $query->fields('n', ['nid']);
	    $query->fields('nfd', ['changed']);
      $query->orderBy('changed' , 'DESC');	
	    $query->condition('d.' . DP_FIELD_NODE_DEPLOY . '_value', 1);
      //For the pagination we need to extend the pagerselectextender and
      //limit in the query
      $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(10);
      $results = $pager->execute()->fetchAll();     
		  $header = [
       'title' => t('title'),  
       'type' => t('type'),
       'updated' => t('Updated'),		 
      ];
	    $output = array();
	    foreach ($results AS $value) {      
	      if(isset($value->nid)) {
	        $node_storage = \Drupal::entityTypeManager()->getStorage('node');
          $node = $node_storage->load($value->nid);
		      $title = $node->get('title')->getvalue();
		      $type = $node->get('type')->getvalue();		
		      $title = $title[0]['value'];
		      $updated = $value->changed;
          $type = $type[0]['target_id'];
          $query = \Drupal::database()->select('dpservices' , 'n');
          $query->fields('n' , array('entity_id'));
          $query->condition('status', 0, "=");
          $query->condition('type', 'node', "=");
          $query->condition('entity_id', $value->nid, "=");
          $results = $query->execute()->fetchAll();
          if(count($results) == 0) {
		        $output[$value->nid] = [
	            'title' => $title,
              'type' => $type,
              'updated' => date("Y-m-d H:i:s" , $updated),			
	          ];
		      }			
	    		
	      }
      }	
      $form['table'] = [
        '#type' => 'tableselect',
        '#header' => $header,
        '#options' => $output,
        '#empty' => t('No contents available for deployment.'),
      ];
      if(count($output) != 0) {        
	      if(!isset($this->dp_username) || !isset($this->dp_password)) {
	        drupal_set_message(t('Set username and password in deploy settings page for authentication.'), 'warning');	             
	      }
        $form['datetime'] = [
          '#title' => 'Chose date to deploy (eg : m/d/Y h:i:sa) :',
          '#type' => 'datetime',
          '#size' => 20,
	        '#date_time_element' => 'text',
	        '#default_value' => '',
	        '#required' => true,
        ];
	      $form['actions']['#type'] = 'actions';
        $form['actions']['submit'] = array(
          '#type' => 'submit',
          '#value' => $this->t('Save'),
          '#button_type' => 'primary',
        );
	      $form['pager'] = array(
          '#type' => 'pager'
        );
	    }
      return $form;
    }
  }
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if(!isset($this->dp_username) || !isset($this->dp_password)) {
      drupal_set_message(t('For authentication, update username and password in deploy settings page.'), 'error');	             
    }
    else {
      $date = $form_state->getValue('datetime')->format('d-m-Y h:i:sa');
	    $date = strtotime($date);
	    $arr_default_nid = $form_state->getValue('table');
	    if(count($arr_default_nid) > 0) {
        foreach($arr_default_nid as $value) {	  
	        if(isset($value) && !empty($value)) {
            $result = \Drupal::database()->insert('dpservices')
	          ->fields(['entity_id' => $value , 'type' => 'node' , 'deploy_date' => $date])->execute();
	        }	  
	      }
	    }
      drupal_set_message('Deployment for node submitted successfully.');
    }		
  }
  public function setDeploySettings() {
    $config = \Drupal::config('dpservices.settings');	
    $this->dp_username = $config->get('dp_username');
	  $this->dp_password = $config->get('dp_password');
  }
}