<?php
/**
 * @file
 * Contains \Drupal\dpservices\Form\Deploysettings.
 */
namespace Drupal\dpservices\Form;


use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface; 

module_load_include('inc', 'dpservices' , 'dpservices.config.inc');

class DpservicesSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'dpservices.settings',
    ];
  }
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dpservices_admin_settings';
  }
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $contentTypes = \Drupal::service('entity.manager')->getStorage('node_type')->loadMultiple();
    $contentTypesList = [];
    foreach ($contentTypes as $contentType) {
      $contentTypesList[$contentType->id()] = $contentType->label();
    }	
	$blockTypes = \Drupal::service('entity.manager')->getStorage('block_content_type')->loadMultiple();
    $blockTypesList = [];
    foreach ($blockTypes as $contentType) {
      $blockTypesList[$contentType->id()] = $contentType->label();
    }	
    $config = $this->config('dpservices.settings');	
    $form['dpservices_request_url'] = array(
      '#type' => 'textfield',
      '#title' => 'Request Url',
	  '#description' => 'Request Url should be included with http:// or https://',
      '#default_value' => $config->get('dp_request_url'),
      '#required' => true,      
    );	
	$form['dpservices_username'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#size' => 25,
	  '#description' => 'Enter username for authentication',
	  '#default_value' => $config->get('dp_username'),
      '#required' => true,	  
    );
	if($config->get('dp_password') == '') {
	  $form['dpservices_pass'] = array(
        '#type' => 'password',
        '#title' => $this->t('Password'),
        '#size' => 25,
	    '#description' => 'Enter password for authentication',
	    '#default_value' => $config->get('dp_password'),	  
        '#required' => true,  
      );	
	}
	else {
		
      $form['dpservices_pass'] = array(
        '#type' => 'password',
        '#title' => $this->t('Password'),
        '#size' => 25,
	    '#description' => 'Enter password for authentication',
	    '#default_value' => $config->get('dp_password'),
      );
	}	
	$form['dpservices_content_type'] = array(
      '#type' => 'checkboxes',
      '#options' => $contentTypesList,
      '#title' => $this->t('Choose the content type to deploy the content'),
      '#default_value' => ($config->get('dp_content_type') != null) ? $config->get('dp_content_type'): array(),
    );
	$form['dpservices_block_type'] = array(
      '#type' => 'checkboxes',
      '#options' => $blockTypesList,
      '#title' => $this->t('Choose the block type to deploy the block'),  
	    '#default_value' => ($config->get('dp_block_type') != null) ? $config->get('dp_block_type'): array(),
    );
    return parent::buildForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('dpservices.settings');
    $dp_content_type = $config->get('dp_content_type');
    $dp_block_type = $config->get('dp_block_type');	
    $config->set('dp_content_type', array('tabs_content' , 'article'));      
	$arr_content_type = $form_state->getValue('dpservices_content_type');
    $arr_block_type = $form_state->getValue('dpservices_block_type');	
	if(count($arr_content_type) > 0) {
	  $field_config = $this->checkNodeFieldName(DP_FIELD_NODE_DEPLOY , 'node');	  
	  if(!isset($field_config)) {
	    $this->createNodeFieldName(DP_FIELD_NODE_DEPLOY , 'node');
	  }
      foreach($arr_content_type as $key => $value) {	  
	    if(isset($value) && !empty($value)) {
          $node_type_field = $this->checkNodeTypeFieldName(DP_FIELD_NODE_DEPLOY , 'node' , $value);		  
		  if(!isset($node_type_field)) {
		    $this->createNodeTypeFieldName(DP_FIELD_NODE_DEPLOY , 'node' , $value);
			$dp_content_type[] = $value;
			$config->set('dp_content_type', $dp_content_type);              
		  }
	    }	  
	  }
	}
    if(count($arr_block_type) > 0) {
      $field_config = $this->checkNodeFieldName(DP_FIELD_BLOCK_DEPLOY , 'block_content');	  
	  if(!isset($field_config)) {
	    $this->createNodeFieldName(DP_FIELD_BLOCK_DEPLOY , 'block_content');
	  }
      foreach($arr_block_type as $key => $value) {	  
	    if(isset($value) && !empty($value)) {
          $node_type_field = $this->checkNodeTypeFieldName(DP_FIELD_BLOCK_DEPLOY , 'block_content' , $value);		  
		  if(!isset($node_type_field)) {
		    $this->createNodeTypeFieldName(DP_FIELD_BLOCK_DEPLOY , 'block_content' , $value);
			$dp_block_type[] = $value;
			$config->set('dp_block_type', $dp_block_type);
		  }
	    }	  
	  }
	}		
    $config->set('dp_request_url', $form_state->getValue('dpservices_request_url'));
    $config->set('dp_username', $form_state->getValue('dpservices_username'));
	$pass = $form_state->getValue('dpservices_pass');
	if($pass != '') {	 
      $config->set('dp_password', $form_state->getValue('dpservices_pass'));
	}	  
	$config->save();
    parent::submitForm($form, $form_state);
  }
  public function checkNodeFieldName($field_name , $entity_type) {
    $field_config = \Drupal\field\Entity\FieldStorageConfig::loadByName($entity_type , $field_name);	
	return $field_config;
  }
  public function checkNodeTypeFieldName($field_name , $entity_type , $content_type) {
    $field_config = \Drupal\field\Entity\FieldConfig::loadByName($entity_type , $content_type , $field_name);
	return $field_config;
  }
  public function createNodeFieldName($field_name , $entity_type) {
    \Drupal\field\Entity\FieldStorageConfig::create(array(
      'field_name' => $field_name,
      'entity_type' => $entity_type,
      'type' => 'boolean',
      'cardinality' => 1,
	  'settings' => array(
      'allowed_values' => array(0 => 0, 1 => 1), //add the default values for the checkbox
      ),
    ))->save();
  }
  public function createNodeTypeFieldName($field_name , $entity_type , $content_type) {
    \Drupal\field\Entity\FieldConfig::create([
      'field_name' => $field_name,
      'entity_type' => $entity_type,
      'bundle' => $content_type,
      'label' => 'Deploy',
    ])->save();
	entity_get_form_display($entity_type, $content_type, 'default')
       ->setComponent($field_name , array(
         'type' => 'boolean_checkbox',
    ))
       ->save();
   }
}
